==> haskell-stm-hamt-1.2.1.1-122.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-hamt
version:              1.2.1.1
visibility:           public
id:                   stm-hamt-1.2.1.1-6Q99VA88jPfA6FGDMnAfhP
key:                  stm-hamt-1.2.1.1-6Q99VA88jPfA6FGDMnAfhP
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  3838957634d92b7ae918889d76cd91d6
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stm-hamt-1.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stm-hamt-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stm-hamt-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.1.1-6Q99VA88jPfA6FGDMnAfhP
depends:
    base-4.18.2.1 deferred-folds-0.9.18.7-3YASkbivcMDDaPil1p3K3o
    focus-1.0.3.2-dqVNbqCJwxApDYKekKDIO
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    list-t-1.0.5.7-AhA7x2MdeKdKv2uigYKj0T
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    primitive-extras-0.10.2.2-KGar6RA4rs7ETQtyDCkLoS
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-hamt-1.2.1.1-123-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-hamt
version:              1.2.1.1
visibility:           public
id:                   stm-hamt-1.2.1.1-HHAwtfZaTzEBCKUhhMngKz
key:                  stm-hamt-1.2.1.1-HHAwtfZaTzEBCKUhhMngKz
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  b3ffa91f4da46a4fd4b7c269baed8c95
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stm-hamt-1.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stm-hamt-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stm-hamt-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.1.1-HHAwtfZaTzEBCKUhhMngKz
depends:
    base-4.18.2.1 deferred-folds-0.9.18.7-AQVjI6sElLgFSTBjW4DXpU
    focus-1.0.3.2-K7eYaaN3rLJIOKNkem96pr
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    list-t-1.0.5.7-FrIBwXDu8V5JPdGMNO7zz5
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    primitive-extras-0.10.2.2-LthNrCLIOaVFjrl0jUcyR0
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
